@@ -15,7 +15,7 @@ Readonly::Scalar our $EMPTY_STR => q{};
 Readonly::Scalar our $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.21;
+our $VERSION = 0.22;
 
 # Pretty print of backtrace.
 sub err_bt_pretty {
@@ -622,13 +622,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Error::Pure>,
-L<Error::Pure::AllError>,
-L<Error::Pure::Die>,
-L<Error::Pure::Error>,
-L<Error::Pure::ErrorList>,
-L<Error::Pure::Print>,
-L<Error::Pure::Utils>,
+=over
+
+=item L<Task::Error::Pure>
+
+Install the Error::Pure modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -642,10 +642,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2008-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.21
+0.22
 
 =cut
